
sPyNNaker - PyNN Simulations on SpiNNaker Hardware
==================================================
This package provides common code for PyNN implementations for SpiNNaker.

We have [user installation instructions](http://spinnakermanchester.github.io/)
which describe in detail more about what is going on.

Developer Installation
----------------------
If you want to be able to edit the source code, but still have it referenced
from other Python modules, you can set the install to be a
[developer install](http://spinnakermanchester.github.io/development/devenv.html)
which describes the process of installing the other modules which these
depend upon for a complete editable install.

Documentation
-------------
[sPyNNaker Python documentation](https://spynnaker.readthedocs.io/en/7.4.0)
<br>
[sPyNNaker C documentation](http://spinnakermanchester.github.io/sPyNNaker/c/)

[Combined PyNN8 python documentation](http://spinnakermanchester.readthedocs.io/en/7.4.0)

